@@ -8,8 +8,10 @@ import numpy as np
 from pyqtgraph.Qt import QtGui, QtWidgets, QtCore
 from pyqtgraph.parametertree import parameterTypes, Parameter, ParameterItem
 from pyqtgraph.parametertree.Parameter import PARAM_TYPES
-from pyqtgraph.parametertree.parameterTypes import ActionParameterItem, ActionParameter, \
-  TextParameterItem, TextParameter
+from pyqtgraph.parametertree.parameterTypes import (
+  ActionParameterItem, ActionParameter,
+  TextParameterItem, TextParameter, WidgetParameterItem
+)
 
 from .prjparam import PrjParam
 from .shortcut import ShortcutsEditor
@@ -93,16 +95,19 @@ class PgPopupDelegate(QtWidgets.QStyledItemDelegate):
 class PgParamDelegate(QtWidgets.QStyledItemDelegate):
   def __init__(self, paramDict: dict, parent=None):
     super().__init__(parent)
-    errMsg = f'{self.__class__} can only create parameter editors from' ' registered pg widgets that implement ' \
-             f'makeWidget() and are in pyqtgraph\'s *PARAM_TYPES*.\n' \
-             f'These requirements are not met for type "{paramDict["type"]}"'
+    errMsg = (
+      f'{self.__class__} can only create parameter editors from registered pg widgets whose items subclass'
+      f' "WidgetParameterItem" and are in pyqtgraph\'s *PARAM_TYPES*.\nThese requirements are not met for type'
+      f' "{paramDict["type"]}"'
+    )
 
     if paramDict['type'] not in PARAM_TYPES:
       raise TypeError(errMsg)
     paramDict.update(name='dummy')
     self.param = param = Parameter.create(**paramDict)
-    if hasattr(param.itemClass, 'makeWidget'):
-      self.item = param.itemClass(param, 0)
+    item = param.makeTreeItem(0)
+    if isinstance(item, WidgetParameterItem):
+      self.item = item
     else:
       raise TypeError(errMsg)
 
@@ -355,217 +360,6 @@ class FilePickerParameterItem(parameterTypes.WidgetParameterItem):
 class FilePickerParameter(Parameter):
   itemClass = FilePickerParameterItem
 
-class SliderParameterItem(parameterTypes.WidgetParameterItem):
-  slider: QtWidgets.QSlider
-  span: np.ndarray
-  charSpan: np.ndarray
-
-  def makeWidget(self):
-    param = self.param
-    opts = param.opts
-    # Bind to self to avoid garbage collection of signal holder
-    # Bind to self to avoid garbage collection of signal holder
-    _emitter = self._emitter = _Emitter()
-
-
-    self.slider = QtWidgets.QSlider()
-    self.slider.setOrientation(QtCore.Qt.Orientation.Horizontal)
-    lbl = QtWidgets.QLabel()
-    lbl.setAlignment(QtCore.Qt.AlignmentFlag.AlignLeft)
-
-    w = QtWidgets.QWidget()
-    layout = QtWidgets.QHBoxLayout()
-    w.setLayout(layout)
-    layout.addWidget(lbl)
-    layout.addWidget(self.slider)
-
-    def setValue(v):
-      self.slider.setValue(self.spanToSliderValue(v))
-    def getValue():
-      return self.span[self.slider.value()].item()
-
-    def vChanged(v):
-      lbl.setText(self.prettyTextValue(v))
-    self.slider.valueChanged.connect(vChanged)
-
-    def onMove(pos):
-      _emitter.sigChanging.emit(self.span[pos].item())
-    self.slider.sliderMoved.connect(onMove)
-
-    w.setValue = setValue
-    w.value = getValue
-    w.sigChanged = self.slider.valueChanged
-    w.sigChanging = _emitter.sigChanging
-    self.optsChanged(param, opts)
-    return w
-
-  # def updateDisplayLabel(self, value=None):
-  #   self.displayLabel.setText(self.prettyTextValue(value))
-
-  def spanToSliderValue(self, v):
-    return int(np.argmin(np.abs(self.span-v)))
-
-  def prettyTextValue(self, v):
-    format_ = self.param.opts.get('format', None)
-    cspan = self.charSpan
-    if format_ is None:
-      format_ = f'{{0:>{cspan.dtype.itemsize}}}'
-    return format_.format(cspan[v].decode())
-
-  def optsChanged(self, param, opts):
-    try:
-      super().optsChanged(param, opts)
-    except AttributeError as ex:
-      pass
-    span = opts.get('span', None)
-    if span is None:
-      step = opts.get('step', 1)
-      start, stop = opts['limits']
-      # Add a bit to 'stop' since python slicing excludes the last value
-      span = np.arange(start, stop+step, step)
-    precision = opts.get('precision', 2)
-    if precision is not None:
-      span = span.round(precision)
-    self.span = span
-    self.charSpan = np.char.array(span)
-    w = self.slider
-    w.setMinimum(0)
-    w.setMaximum(len(span)-1)
-
-  def limitsChanged(self, param, limits):
-    self.optsChanged(param, dict(limits=limits))
-
-class SliderParameter(Parameter):
-  itemClass = SliderParameterItem
-
-class ChecklistParameterItem(parameterTypes.GroupParameterItem):
-  def __init__(self, param, depth):
-    self.btnGrp = QtWidgets.QButtonGroup()
-    self.btnGrp.setExclusive(False)
-    self._constructMetaBtns()
-
-    super().__init__(param, depth)
-
-  def _constructMetaBtns(self):
-    self.metaBtnWidget = QtWidgets.QWidget()
-    self.metaBtnLayout = lay = QtWidgets.QHBoxLayout(self.metaBtnWidget)
-    lay.setContentsMargins(0, 0, 0, 0)
-    lay.setSpacing(2)
-    self.metaBtns = {}
-    lay.addStretch(0)
-    for title in 'Clear', 'Select':
-      self.metaBtns[title] = btn = QtWidgets.QPushButton(f'{title} All')
-      self.metaBtnLayout.addWidget(btn)
-      btn.clicked.connect(getattr(self, f'{title.lower()}AllClicked'))
-
-  def treeWidgetChanged(self):
-    ParameterItem.treeWidgetChanged(self)
-    tw = self.treeWidget()
-    if tw is None:
-      return
-    tw.setItemWidget(self, 1, self.metaBtnWidget)
-
-  def selectAllClicked(self):
-    self.param.setValue(list(self.param.names))
-
-  def clearAllClicked(self):
-    self.param.setValue([])
-
-  def insertChild(self, pos, item):
-    ret = super().insertChild(pos, item)
-    self.btnGrp.addButton(item.widget)
-
-  def takeChild(self, i):
-    child = super().takeChild(i)
-    self.btnGrp.removeButton(child.widget)
-
-  def optsChanged(self, param, opts):
-    if 'exclusive' in opts:
-      excl = opts['exclusive']
-      self.btnGrp.setExclusive(excl)
-      for btn in self.metaBtns.values():
-        btn.setDisabled(excl)
-    if 'enabled' in opts:
-      for btn in self.metaBtns.values():
-        btn.setEnabled(opts['expanded'])
-
-  def expandedChangedEvent(self, expanded):
-    for btn in self.metaBtns.values():
-      btn.setVisible(expanded)
-
-class ChecklistParameter(parameterTypes.GroupParameter):
-  itemClass = ChecklistParameterItem
-
-  def __init__(self, **opts):
-    # Value setting before init causes problems since limits aren't set by that point.
-    # Avoid by taking value out of consideration until later
-    opts.setdefault('limits', [])
-    opts.setdefault('value', opts['limits'])
-    super().__init__(name=opts.pop('name'), exclusive=opts.pop('exclusive', False), value=opts.pop('value'))
-    self.sigLimitsChanged.connect(self.updateLimits)
-    self.sigOptionsChanged.connect(self.optsChanged)
-    self.setLimits(opts.pop('limits', []))
-    self.setOpts(**opts)
-
-  def updateLimits(self, _param, limits):
-    oldOpts = self.names
-    val = self.opts['value']
-    # Make sure adding and removing children don't cause tree state changes
-    self.blockTreeChangeSignal()
-    self.clearChildren()
-    exclusive = self.opts['exclusive']
-    for chOpts in limits:
-      if isinstance(chOpts, str):
-        # Recycle old values if they match the new limits
-        newVal = oldOpts.get(chOpts, False)
-        chOpts = dict(name=chOpts, value=newVal)
-      child = self.create(type='bool', **chOpts)
-      # Prevent child from broadcasting tree state changes
-      self.addChild(child)
-      child.blockTreeChangeSignal()
-      child.sigValueChanged.connect(self._onSubParamChange)
-    # Purge child changes before unblocking
-    self.treeStateChanges.clear()
-    self.unblockTreeChangeSignal()
-    if exclusive and limits:
-      setVal = val[-1] if val else limits[-1]
-    else:
-      setVal = val
-    if setVal is not None:
-      self.setValue(setVal)
-
-  def _onSubParamChange(self, param, value):
-    # Old value will become false, new value becomes true. Only fire on new value = true for exclusive
-    if not value and self.opts['exclusive']:
-      return
-    elif self.opts['exclusive']:
-      return self.setValue(param.name())
-    # Interpret value, fire sigValueChanged
-    return self.setValue(self.value())
-
-  def optsChanged(self, param, opts):
-    if 'exclusive' in opts:
-      self.updateLimits(param, self.opts.get('limits', []))
-
-  def value(self):
-    vals = [p.name() for p in self.children() if p.value()]
-    exclusive = self.opts['exclusive']
-    if not vals and exclusive:
-      return None
-    elif exclusive:
-      return vals[0]
-    else:
-      return vals
-
-  def setValue(self, value, blockSignal=None):
-    exclusive = self.opts['exclusive']
-    # Will emit at the end, so no problem discarding existing changes
-    cmpVal = value if isinstance(value, list) else [value]
-    for chParam in self:
-      checked = chParam.name() in cmpVal
-      chParam.setValue(checked, self._onSubParamChange)
-    super().setValue(value, blockSignal)
-
 class NoneParameter(parameterTypes.SimpleParameter):
 
   def __init__(self, **opts):
@@ -581,5 +375,3 @@ parameterTypes.registerParameterType('shortcutkeyseq',  ShortcutKeySeqParameter,
 parameterTypes.registerParameterType('shortcut',        ShortcutParameter,        override=True)
 parameterTypes.registerParameterType('popuplineeditor', PopupLineEditorParameter, override=True)
 parameterTypes.registerParameterType('filepicker',      FilePickerParameter,      override=True)
-parameterTypes.registerParameterType('slider',          SliderParameter,          override=True)
-parameterTypes.registerParameterType('checklist',       ChecklistParameter,       override=True)
