@@ -15,6 +15,9 @@ def _rescale(data, min_, max_):
 _specialKeys = ['name', 'value', 'helpText', 'pType']
 class _UNSPECIFIED_DEFAULT: pass
 class PrjParam:
+  comparator = str
+  """Function for determining =/</> when comparing to another object"""
+
   def __init__(self, name: str, value=None, pType: Optional[str]=None, helpText='',
                **opts):
     """
@@ -80,17 +83,17 @@ class PrjParam:
     :param other: Other :class:`PrjParam` member for comparison
     :return: Whether `self` is less than `other`
     """
-    return repr(self) < repr(other)
+    return self.comparator(self) < self.comparator(other)
 
   def __eq__(self, other):
     # TODO: Highly naive implementation. Be sure to make this more robust if it needs to be
     #   for now assume only other prjparamss will be passed in
-    return repr(self) == repr(other)
+    return self.comparator(self) == self.comparator(other)
 
   def __hash__(self):
     # Since every param within a group will have a unique name, just the name is
     # sufficient to form a proper hash
-    return hash(repr(self),)
+    return hash(self.comparator(self),)
 
   def toNumeric(self, data: Sequence, rescale=False, returnMapping=False):
     """
